https://svn.lrde.epita.fr/svn/lrdetools/trunk
Index: ChangeLog
from Nicolas Pouillard <ertai(a)lrde.epita.fr>
Fix some typos, and add acknowledgments.
* vcs/NEWS,
* vcs/lib/vcs/vcs.rb,
* vcs/lib/vcs/junk.rb,
* vcs/lib/vcs/common_commit.rb: Update.
NEWS | 13 +++++++------
lib/vcs/common_commit.rb | 2 +-
lib/vcs/junk.rb | 4 ++--
lib/vcs/vcs.rb | 4 ++--
4 files changed, 12 insertions(+), 11 deletions(-)
Index: vcs/NEWS
--- vcs/NEWS (revision 256)
+++ vcs/NEWS (working copy)
@@ -48,26 +48,27 @@
* Commands:
- svn list:
- - Now support category listing:
+ - Now supports category listing:
- list all junk files in foo:
svn list --junk foo
- list all precious, and unmasked files:
svn list --precious --unmask
- - Action support (--do switch):
+ - Action supports (--do switch):
- svn list --junk --do rm
- svn list --precious --do wc
- svn junk: This command use `list' to remove all junk files.
* Sorted outputs:
- - Vcs now support sorting!!!
+ - Vcs now supports sorting:
In a .vcs configuration file you can add a `sorting' key which
- contains a list of regular expressions.
+ contains a list of regular expressions (Thanks to Akim Demaille and
+ Alexandre Borghi for this idea).
For example:
>>>> ~/.vcs <<<<
---
sorting:
- - !re (NEWS|README|TODO) # These files in first
+ - !re (NEWS|README|TODO) # These files first
- !re src/ # Then the src directory
- !re test/ # Then the test directory
- !re parse/ # parse and ast are subdirectories
@@ -87,7 +88,7 @@
# - test/parse/a.cc
# - test/ast/a.hh
# - test/ast/a.cc
- - Affected commands:
+ - Concerned commands:
- status
- diffw (a more human readable diff)
- mk_log_entry
Index: vcs/lib/vcs/junk.rb
--- vcs/lib/vcs/junk.rb (revision 256)
+++ vcs/lib/vcs/junk.rb (working copy)
@@ -7,10 +7,10 @@
class Vcs
# This command removes all junk files (by default all files begining with `,').
- # Warning: this command removes some files that may contains some relevant
+ # Warning: this command removes some files that may contains some important
# information. For example during a commit the information that you type is
# stored in one of these `,files'. So be careful using this command.
- # See the user configuration to customize what is considered as a junk file.
+ # See the user configuration to customize what is considered a junk file.
def junk! ( files=[], options={} )
list!(files, options.merge(:junk => true)) do |path_list|
path_list.each { |path| logger.info { "Remove #{path}" } }
Index: vcs/lib/vcs/common_commit.rb
--- vcs/lib/vcs/common_commit.rb (revision 256)
+++ vcs/lib/vcs/common_commit.rb (working copy)
@@ -27,7 +27,7 @@
raise Failure, "
|You have unrecognized files in your working copy !
|This meant that these files won't be commited !
- |You have some solutions to get rid of this limitation:
+ |You have some solutions to comply with the rule:
|- You must put these files in some categories.
| For instance you can rename these files and put a `+' before
| to make it `precious':
>>> "Nicolas" == Nicolas Pouillard <ertai(a)lrde.epita.fr> writes:
> + raise Failure, "
> + |You have unrecognized files in your working copy !
pas d'espace devant la ponctuation.
> + |This meant that these files won't be commited !
> + |You have some solutions to get rid of this limitation:
Mauvaise phrase, c'est pas une limitation.
> + |- You must put these files in some categories.
> + | For instance you can rename these files and put a `+' before
> + | to make it `precious':
> + | put `,' for `junk'
> + | put `\\' for `unmask'
> + | put `-' for `exclude'
> + |- You can also edit your configuration file (.vcs) to customize
> + | these categories. For example add this:
> + | ------------ .vcs ------------
> + | precious:
> + | - !re my_precious_file[0-9]*
> + | - !re .*\.patch
> + | ------------ .vcs ------------
> + |- You can also perform a partial commit and specify which files
> + | and directories commit. For example this command:
> + | #{@command} commit foo.c bar/
> + |
> + |Commit failed".head_cut!
> + end
> +
> Vcs.commited = edit_form!(files)
> message(files)
>>> "Nicolas" == Nicolas Pouillard <ertai(a)lrde.epita.fr> writes:
> https://svn.lrde.epita.fr/svn/lrdetools/trunk
> Index: ChangeLog
> from Nicolas Pouillard <ertai(a)lrde.epita.fr>
> Fix a bug woth error handlers.
Il faudrait sans doute mettre un correcteur orthographique...
>>> "Nicolas" == Nicolas Pouillard <ertai(a)lrde.epita.fr> writes:
> + # This command removes all junk files (by default all files begining with `,').
> + # Warning: this command removes some files that may contains some relevant
contain
relevant -> important
> + # information. For example during a commit the information that you type is
> + # stored in one of these `,files'. So be careful using this command.
> + # See the user configuration to customize what is considered as a junk file.
s/as//
>>> "Nicolas" == Nicolas Pouillard <ertai(a)lrde.epita.fr> writes:
> + # This method can be called just one time to avoid conflicts
Once. Point final.
> def default_commit ( meth )
> + just_one_time do
Ditto.
> alias_command :commit, meth
> alias_command :ci, meth
> end
> + end
> end # class << self
>>> "Nicolas" == Nicolas Pouillard <ertai(a)lrde.epita.fr> writes:
> https://svn.lrde.epita.fr/svn/lrdetools/trunk
> Index: ChangeLog
> from Nicolas Pouillard <ertai(a)lrde.epita.fr>
> Files categories: closer to GNU Arch.
This is nice.
And thanks for the acknowledgment.
Index: vcs/lib/vcs/vcs.rb
--- vcs/lib/vcs/vcs.rb (revision 256)
+++ vcs/lib/vcs/vcs.rb (working copy)
@@ -598,9 +598,9 @@
end
# Set the given method as default commit action, use commit_ for the old one
# This method can be called just one time to avoid conflicts
def default_commit ( meth )
- just_one_time do
+ just_once do
alias_command :commit, meth
alias_command :ci, meth
end
@@ -598,9 +598,9 @@
end
# Set the given method as default commit action, use commit_ for the old one
- # This method can be called just one time to avoid conflicts
+ # This method can be called just once to avoid conflicts
def default_commit ( meth )